django_premailer — django-premailer 0.1.0 documentation

# django_premailer

- django_premailer package
  - Subpackages
    - django_premailer.templatetags package
      - Submodules
      - django_premailer.templatetags.premailer module
      - Module contents
    - django_premailer.tests package
      - Subpackages
      - Submodules
      - django_premailer.tests.test_templatetags module
      - Module contents
  - Submodules
  - django_premailer.models module
  - Module contents